"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const sgf = require("staged-git-files");
const util = require("util");
const validateMessage = require("validate-commit-msg");
const base_1 = require("../base");
const run_1 = require("../base/run");
const eslint_1 = require("../services/eslint");
const message_1 = require("../services/message");
const util_1 = require("../util");
const run_2 = require("./run");
class Lint extends run_1.default {
    async run() {
        const { flags } = this.parse(Lint);
        if (flags.commitMsg) {
            if (!validateMessage(flags.commitMsg)) {
                throw Error(message_1.MCOMMON.INVALID_COMMIT_MSG_FORMAT);
            }
            return;
        }
        if (flags.staged) {
            let filenames = [];
            await util.promisify(sgf)('ACM').then(files => {
                filenames = files.map(file => file.filename);
            });
            filenames = eslint_1.default.getLintFiles(filenames);
            flags.extras = filenames.join(' ');
            delete flags.staged;
        }
        else {
            flags.extras = ['app/', 'template/'].join(' ');
        }
        const list = util_1.default.restoreFlags(flags);
        await run_2.default.run(['lint', ...list]);
    }
}
Lint.strict = false;
Lint.examples = [
    '$ rde lint',
];
Lint.flags = Object.assign({}, base_1.default.flags, run_2.default.flags, { staged: command_1.flags.boolean({
        char: 's',
        description: 'lint staged',
    }), commitMsg: command_1.flags.string({
        char: 'm',
        description: 'commit msg',
    }) });
exports.default = Lint;
