"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const child_process_1 = require("child_process");
const spawn = require("cross-spawn");
const fs = require("fs");
const path = require("path");
const copy = require("recursive-copy");
const util = require("util");
const asyncExec = util.promisify(child_process_1.exec);
exports.default = {
    isEmptyDir(dir) {
        const files = fs.readdirSync(dir);
        return files.length === 0;
    },
    ensureRequire(path) {
        if (!fs.existsSync(path)) {
            throw Error(`${path} cannot be found, please check`);
        }
        // @ts-ignore
        delete require.cache[path];
        return require(path);
    },
    async asyncExec(cmd) {
        return asyncExec(cmd);
    },
    async asyncSpawn(cmd, args = [], options = {}) {
        const child = spawn(cmd, args, Object.assign({ stdio: 'inherit' }, options));
        return new Promise((resolve, reject) => {
            child.on('error', reject);
            child.on('exit', code => {
                if (code === 0) {
                    resolve();
                }
                else {
                    const err = new Error(`child exited with code ${code}`);
                    reject(err);
                }
            });
        });
    },
    restoreFlags(flags) {
        const list = [];
        Object.keys(flags).forEach(key => {
            list.push(`--${key}`);
            if (typeof flags[key] !== 'boolean') {
                list.push(`${flags[key]}`);
            }
        });
        return list;
    },
    async copy(src, dest, mapping) {
        let options = Object.assign({ overwrite: true, dot: true }, mapping.options, { rename(filePath) {
                // fix rename problem if src type is file
                if (fs.lstatSync(src).isFile() && mapping.options && mapping.options.rename) {
                    const name = mapping.options.rename(path.basename(src));
                    return `../${name}`;
                }
                return filePath;
            } });
        await copy(src, dest, options);
    },
};
